==> gammaray_2.0.1.orig.tar.xz: gammaray-2.0.1/plugins/widgetinspector/paintbufferreplaywidget.h <==
/*
  paintbufferreplaywidget.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2012-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_PAINTBUFFERREPLAYWIDGET_H
#define GAMMARAY_PAINTBUFFERREPLAYWIDGET_H

#include "config-gammaray.h"

#include <QWidget>

namespace GammaRay {

/**
 * A widget painting a certain sub-set of a QPaintBuffer.
 */
class PaintBufferReplayWidget : public QWidget
{
  Q_OBJECT
  public:
    explicit PaintBufferReplayWidget(QWidget *parent = 0);

    virtual QSize sizeHint() const;

  public slots:
    void setZoomFactor(int zoom);
    void setPixmap(const QPixmap &pixmap);

  protected:
    virtual void paintEvent(QPaintEvent *event);

  private:
    QPixmap m_pixmap;
    int m_zoomFactor;
};

}

#endif // GAMMARAY_PAINTBUFFERREPLAYWIDGET_H

==> gammaray_2.1.0.orig.tar.xz: gammaray-2.1.0/plugins/widgetinspector/paintbufferreplaywidget.h <==
/*
  paintbufferreplaywidget.h

  This file is part of GammaRay, the Qt application inspection and
  manipulation tool.

  Copyright (C) 2012-2014 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
  Author: Volker Krause <volker.krause@kdab.com>

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 2 of the License, or
  (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef GAMMARAY_WIDGETINSPECTOR_PAINTBUFFERREPLAYWIDGET_H
#define GAMMARAY_WIDGETINSPECTOR_PAINTBUFFERREPLAYWIDGET_H

#include "config-gammaray.h"

#include <QWidget>

namespace GammaRay {

/**
 * A widget painting a certain sub-set of a QPaintBuffer.
 */
class PaintBufferReplayWidget : public QWidget
{
  Q_OBJECT
  public:
    explicit PaintBufferReplayWidget(QWidget *parent = 0);

    virtual QSize sizeHint() const;

  public slots:
    void setZoomFactor(int zoom);
    void setPixmap(const QPixmap &pixmap);

  protected:
    virtual void paintEvent(QPaintEvent *event);

  private:
    QPixmap m_pixmap;
    int m_zoomFactor;
};

}

#endif // GAMMARAY_PAINTBUFFERREPLAYWIDGET_H
